Crate java_mapping_serde

Crate java_mapping_serde 

Framework for Java deobfuscation mapping serialization and deserialization.

Modules

de
Deserialization based on visitors.
ser
Serialization.

Traits

Deserialize
A type that can be deserialized from a Deserializer.
Deserializer
Deserializer of a mapping file.
Serialize
Type that could be serialized into a mapping file through Serializer.
Serializer
Serializer of a mapping file.