Module ser

Module ser 

Serialization.

Structs

Impossible
Helper type for implementing a Serializer that does not support serializing one of the element types.
Skip
Helper type for implementing a Serializer that skips serializing one of the element types.

Traits

Error
Error type used by a serializer.
Serialize
Type that could be serialized into a mapping file through Serializer.
Serializer
Serializer of a mapping file.